@@ -24,7 +24,7 @@ PIPE_OUT = not sys.stdout.isatty()
 QUIT_KEYS = ['q', readchar.key.ESC, '\n', '\r',' ']
 
 vinca_path = Path(__file__).parent 
-cards_path = vinca_path / 'cards'
+cards_path = Path.home() / 'cards'
 ALL_CARDS = [Card(int(id.name)) for id in cards_path.iterdir()] # TODO: load cards otf
 ALL_TAGS = [tag for card in ALL_CARDS for tag in card.tags] # TODO: cache
 
@@ -308,6 +308,7 @@ def display_filter(args):
 	if len(matches) > 10:
 		ansi.light()
 		print(f'10 of {len(matches)}')
+		ansi.reset()
 	ansi.line_wrap_off()
 	for card in matches[:10]:
 		if card.due_as_of(TODAY):
